Module testing

Module testing 

Structs

Corpus
A corpus is a collection of examples for testing.
Example
A corpus example: input text and expected outputs.

Functions

check_corpus
Check a corpus against a set of rules and return failures.